Release Notes
=============

Version 0.3
-----------
 * New setuptools-based build system
 * New, improved documentation
 * Added post-acquisition beam forming module
 * Added in modules for writing simulated data to the S60, TBW, TBN, and 
 * DRX raw data formats
 * Added a module for simulated basic test signals in TBW, TBN, and DRX data
 * Moved the lwa_user script 'astrostatus.py' into the scripts directory
 * Fixed the FITS IDI writer
 * Fixed a couple of bugs dealing with incorrect chunking of data in scripts/tbwSpectra.py and scripts/tbnSpectra.py

Version 0.2
-----------
 * Added in other modules from the lwa_user library developed by NRL

Version 0.1
-----------
 * Initial version
